{% extends 'cjkcms/blocks/base_block.html' %}
{% load wagtailcore_tags %}
{% block block_render %}
{% with page=self.page.specific %}
{% include page.miniview_template %}
{% endwith %}
{% endblock %}
