# Generated by Django 4.2.2 on 2023-07-02 17:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0010_filmstrip_filmpanel"),
    ]

    operations = [
        migrations.AddField(
            model_name="cjkcmspage",
            name="related_classifier_term",
            field=models.ForeignKey(
                blank=True,
                help_text="When getting related pages, pages with this term will be weighted over other classifier terms. By default, pages with the greatest number of classifiers in common are ranked highest.",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="cjkcms.classifierterm",
                verbose_name="Preferred related classifier term",
            ),
        ),
        migrations.AddField(
            model_name="cjkcmspage",
            name="related_num",
            field=models.PositiveIntegerField(
                default=3, verbose_name="Number of related pages to show"
            ),
        ),
        migrations.AddField(
            model_name="cjkcmspage",
            name="related_show",
            field=models.BooleanField(
                default=False, verbose_name="Show list of related pages"
            ),
        ),
    ]
