{% load wagtailsettings_tags %}
<script>
    var _paq = window._paq = window._paq || [];
    {% if settings.cjkcms.AnalyticsSettings.matomo_disable_cookies %}
    _paq.push(["disableCookies"]);
    {% endif %}
    _paq.push(['trackPageView']);
    _paq.push(['enableLinkTracking']);
    (function() {
      var u="{{settings.cjkcms.AnalyticsSettings.matomo_hostname}}/";
      _paq.push(['setTrackerUrl', u+'matomo.php']);
      _paq.push(['setSiteId', '{{settings.cjkcms.AnalyticsSettings.matomo_site_id}}']);
      var d=document, g=d.createElement('script'), s=d.getElementsByTagName('script')[0];
      g.async=true; g.src=u+'matomo.js'; s.parentNode.insertBefore(g,s);
    })();
</script>
